@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -192,7 +192,7 @@ typedef gint64 goffset;
 #define IS_ASCII(c) (((guchar) c) <= 0177 ? 1 : 0)
 
 /* from NetworkManager */
-#if HAVE_BACKTRACE
+#if (defined(HAVE_BACKTRACE) && !defined(__FreeBSD__))
 #define print_backtrace()						\
 G_STMT_START								\
 {									\
@@ -287,13 +287,6 @@ guint str_case_hash		(gconstpointer	 key);
 
 void ptr_array_free_strings	(GPtrArray	*array);
 
-typedef gboolean (*StrFindFunc) (const gchar	*haystack,
-				 const gchar	*needle);
-
-gboolean str_find		(const gchar	*haystack,
-				 const gchar	*needle);
-gboolean str_case_find		(const gchar	*haystack,
-				 const gchar	*needle);
 /* number-string conversion */
 gint to_number			(const gchar *nstr);
 gchar *itos_buf			(gchar	     *nstr,
