@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2009 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -83,6 +83,8 @@ struct _FolderView
 	GtkUIManager *ui_manager;
 	GtkActionGroup *popup_common_action_group;
 	GtkActionGroup *popup_specific_action_group;
+	gint scroll_timeout_id;
+	gint scroll_value;
 };
 
 struct _FolderViewPopup
@@ -133,7 +135,7 @@ void folderview_move_folder		(FolderView 	*folderview,
 
 void folderview_set_target_folder_color (gint		color_op);
 
-void folderview_reflect_prefs_pixmap_theme	(FolderView *folderview);
+void folderview_reinit_fonts		(FolderView *folderview);
 
 void folderview_reflect_prefs		(void);
 void folderview_register_popup		(FolderViewPopup	*fpopup);
