@@ -1,10 +1,8 @@
+/* A Bison parser, made by GNU Bison 2.5.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
-
-/* Skeleton interface for Bison's Yacc-like parsers in C
+/* Bison interface for Yacc-like parsers in C
    
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
+      Copyright (C) 1984, 1989-1990, 2000-2011 Free Software Foundation, Inc.
    
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -132,20 +130,24 @@
      MATCHER_WATCH = 348,
      MATCHER_SPAM = 349,
      MATCHER_NOT_SPAM = 350,
-     MATCHER_TAG = 351,
-     MATCHER_NOT_TAG = 352,
-     MATCHER_SET_TAG = 353,
-     MATCHER_UNSET_TAG = 354,
-     MATCHER_TAGGED = 355,
-     MATCHER_NOT_TAGGED = 356,
-     MATCHER_CLEAR_TAGS = 357,
-     MATCHER_ENABLED = 358,
-     MATCHER_DISABLED = 359,
-     MATCHER_RULENAME = 360,
-     MATCHER_ACCOUNT = 361,
-     MATCHER_STRING = 362,
-     MATCHER_SECTION = 363,
-     MATCHER_INTEGER = 364
+     MATCHER_HAS_ATTACHMENT = 351,
+     MATCHER_HAS_NO_ATTACHMENT = 352,
+     MATCHER_SIGNED = 353,
+     MATCHER_NOT_SIGNED = 354,
+     MATCHER_TAG = 355,
+     MATCHER_NOT_TAG = 356,
+     MATCHER_SET_TAG = 357,
+     MATCHER_UNSET_TAG = 358,
+     MATCHER_TAGGED = 359,
+     MATCHER_NOT_TAGGED = 360,
+     MATCHER_CLEAR_TAGS = 361,
+     MATCHER_ENABLED = 362,
+     MATCHER_DISABLED = 363,
+     MATCHER_RULENAME = 364,
+     MATCHER_ACCOUNT = 365,
+     MATCHER_STRING = 366,
+     MATCHER_SECTION = 367,
+     MATCHER_INTEGER = 368
    };
 #endif
 /* Tokens.  */
@@ -242,20 +244,24 @@
 #define MATCHER_WATCH 348
 #define MATCHER_SPAM 349
 #define MATCHER_NOT_SPAM 350
-#define MATCHER_TAG 351
-#define MATCHER_NOT_TAG 352
-#define MATCHER_SET_TAG 353
-#define MATCHER_UNSET_TAG 354
-#define MATCHER_TAGGED 355
-#define MATCHER_NOT_TAGGED 356
-#define MATCHER_CLEAR_TAGS 357
-#define MATCHER_ENABLED 358
-#define MATCHER_DISABLED 359
-#define MATCHER_RULENAME 360
-#define MATCHER_ACCOUNT 361
-#define MATCHER_STRING 362
-#define MATCHER_SECTION 363
-#define MATCHER_INTEGER 364
+#define MATCHER_HAS_ATTACHMENT 351
+#define MATCHER_HAS_NO_ATTACHMENT 352
+#define MATCHER_SIGNED 353
+#define MATCHER_NOT_SIGNED 354
+#define MATCHER_TAG 355
+#define MATCHER_NOT_TAG 356
+#define MATCHER_SET_TAG 357
+#define MATCHER_UNSET_TAG 358
+#define MATCHER_TAGGED 359
+#define MATCHER_NOT_TAGGED 360
+#define MATCHER_CLEAR_TAGS 361
+#define MATCHER_ENABLED 362
+#define MATCHER_DISABLED 363
+#define MATCHER_RULENAME 364
+#define MATCHER_ACCOUNT 365
+#define MATCHER_STRING 366
+#define MATCHER_SECTION 367
+#define MATCHER_INTEGER 368
 
 
 
@@ -264,16 +270,16 @@
 typedef union YYSTYPE
 {
 
-/* Line 1676 of yacc.c  */
-#line 302 "matcher_parser_parse.y"
+/* Line 2068 of yacc.c  */
+#line 309 "matcher_parser_parse.y"
 
 	char *str;
 	int value;
 
 
 
-/* Line 1676 of yacc.c  */
-#line 277 "matcher_parser_parse.h"
+/* Line 2068 of yacc.c  */
+#line 283 "matcher_parser_parse.h"
 } YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
