@@ -1,6 +1,6 @@
 /*
  * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 2001-2007 Hiroyuki Yamamoto and the Claws Mail team
+ * Copyright (C) 2001-2012 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -198,6 +198,8 @@ enum {
 
 	A_SEPARATOR,
 
+	A_CLAWS_PLUGINS,
+
 	N_ACTION_VAL
 };
 
@@ -262,4 +264,5 @@ void toolbar_set_learn_button		(Toolbar	*toolbar,
 					 LearnButtonType  learn_btn_type);
 const gchar *toolbar_get_short_text	(int action);
 int	     toolbar_get_icon		(int action);
+gboolean toolbar_check_action_btns	(ToolbarType	type);
 #endif /* __CUSTOM_TOOLBAR_H__ */
